# kroki

Access kroki from python

To install:	```pip install kroki```

# Examples

```python
from kroki import get_diagram_image

get_diagram_image('Bob->Alice : Hello!', diagram_kind='plantuml', output_format='svg')

```

<img width="123" alt="image" src="https://user-images.githubusercontent.com/1906276/211854316-501ec323-bd26-4428-a722-2fa200bfbea3.png">


